@@ -2,13 +2,14 @@ from .between import between
 from .email import email
 from .extremes import Min, Max
 from .ip_address import ipv4, ipv6
+from .i18n import fi_business_id, fi_ssn
 from .length import length
 from .mac_address import mac_address
+from .slug import slug
 from .truthy import truthy
 from .url import url
 from .utils import ValidationFailure, validator
 from .uuid import uuid
-from .i18n import fi_business_id, fi_ssn
 
 
 __all__ = (
@@ -20,6 +21,7 @@ __all__ = (
     ipv6,
     length,
     mac_address,
+    slug,
     truthy,
     url,
     uuid,
@@ -30,4 +32,4 @@ __all__ = (
 )
 
 
-__version__ = '0.5'
+__version__ = '0.6'
