@@ -35,6 +35,10 @@ class ValidationFailure(object):
 
 
 def func_args_as_dict(func, args, kwargs):
+    """
+    Returns given function positional and key value arguments as an ordered
+    dictionary.
+    """
     arg_names = list(
         OrderedDict.fromkeys(
             itertools.chain(
@@ -50,6 +54,35 @@ def func_args_as_dict(func, args, kwargs):
 
 
 def validator(func, *args, **kwargs):
+    """
+    A decorator that makes given function validator. Whenever the given
+    function is called and returns False value this decorator returns
+    ValidationFailure object.
+
+    Example:
+
+    ::
+
+
+        >>> from validators import validator
+
+
+        >>> @validator
+        >>> def even(value):
+        ...     return not (value % 2)
+
+
+        >>> even(4)
+        True
+
+        >>> even(5)
+        ValidationFailure(func=even, args={'value': 5})
+
+
+    :param func: function to decorate
+    :param *args: positional function arguments
+    :param **kwargs: key value function arguments
+    """
     def wrapper(func, *args, **kwargs):
         value = func(*args, **kwargs)
         if not value:
